@@ -464,8 +464,7 @@ def picking_details(request_id):
         $ref: "#/definitions/Error message"
     """
     picking = PickingRequest(request_id)
-    response = picking.details()
-    # response = picking.status()['content']
+    response = picking.details()['content']
     API_LOGS.logger.info(response)
 
     return jsonify(response)
